@@ -1,3 +1,5 @@
+import sqlalchemy_filter.exceptions
+
 __all__ = ["FilterSetMixin"]
 
 
@@ -6,10 +8,12 @@ class FilterSetMixin:
 
     def filter_query(self, query, filter_params):
         if not hasattr(self, "filter_class") or self.filter_class is None:
-            raise Exception("Should be declared filter_class for using FilterSetMixin")
+            raise sqlalchemy_filter.exceptions.FilterException(
+                "Should be declared filter_class for using FilterSetMixin"
+            )
 
         filter_ = self.filter_class()
         if not hasattr(filter_, "filter_query"):
-            raise Exception("Unknown filter_class")
+            raise sqlalchemy_filter.exceptions.FilterException("Unknown filter_class")
 
         return filter_.filter_query(query, filter_params)
